---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
A small test case to show the issue is preferred. If not possible, provide whatever useful information
you feel may be able to assist in narrowing down how to reproduce the issue.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment:**
 - OS: [e.g. iOS]
 - Python Version [e.g. 11.1]

**Additional context**
Add any other context about the problem here.
